@@ -21,7 +21,7 @@ class InvalidSignature(NotificationValidationError):
 
 
 class NotificationHandler(object):
-    def __init__(wsdl_url=WSDL_URL):
+    def __init__(self, wsdl_url=WSDL_URL):
         self.client = EbaySuds(wsdl_url)
 
     def decode(self, payload_type, message):
